-- CREATION DATE: 12-10-2012 --
-- MODIFIED DATE: 30-09-2013 --
-- Vtg -- VludsTillerGifts
------------------------------------------------------------------------------------------------------

local Vtg_tItemIdToRepId = {
	[74642] = { 1279 },	--Charbroiled Tiger Steak
	[74643] = { 1273 },	--Sauteed Carrots
	[74644] = { 1281 },	--Swirling Mist Soup
	[74645] = { 1278 },	--Eternal Blossom Fish
	[74647] = { 1277 },	--Valley Stir Fry
	[74649] = { 1276 },	--Braised Turtle
	[74651] = { 1275 },	--Shrimp Dumplings
	[74652] = { 1280 },	--Fire Spirit Salmon
	[74654] = { 1283 },	--Wildfowl Roast
	[74655] = { 1282 },	--Twin Fish Platter

	[79264] = { 1279, 1280 },	--Ruby Shard
	[79265] = { 1277, 1276 },	--Blue Feather
	[79266] = { 1275, 1282 },	--Jade Cat
	[79267] = { 1273, 1278 },	--Lovely Apple
	[79268] = { 1283, 1281 },	--Marsh Lily
}

local Vtg_tRawIdToCookedId = {
	[74833] = { 74642 },	--Raw Tiger Steak
	[74837] = { 74649 },	--Raw Turtle Meat
	[74839] = { 74647, 74654 },	--Wildfowl Breast
	[74841] = { 74649, 74643 },	--Juicycrunch Carrot
	[74843] = { 74652 },	--Scallions
	[74848] = { 74645 },	--Striped Melon
	[74856] = { 74644, 74645 },	--Jade Lungfish
	[74857] = { 74651 },	--Giant Mantis Shrimp
	[74859] = { 74652 },	--Emperor Salmon
	[74864] = { 74647 },	--Reef Octopus
	[74865] = { 74655 },	--Krasarang Paddlefish
}

local Vtg_tNpcIdToRepId = {
	[57298] = 1283,
	[57402] = 1279,
	[58647] = 1275,
	[58705] = 1282,
	[58706] = 1281,
	[58707] = 1276,
	[58708] = 1278,
	[58709] = 1277,
	[58710] = 1273,
	[58761] = 1280,
	[63721] = 1358,
	[64337] = 1357,
}

------------------------------------------------------------------------------------------------------
-- OnTooltipSetItem
local function VtgOnTooltipSetItem(oTip, ...)
	local sName, sLink = oTip:GetItem()
	if sLink then
		local nItemId = tonumber(sLink:match("item:(%d+)"))
		if nItemId ~= nil then
			if Vtg_tRawIdToCookedId[nItemId] then
				for _, nFoodId in pairs(Vtg_tRawIdToCookedId[nItemId]) do
					local sFood = GetItemInfo(nFoodId)
					if sFood == nil then
						sFood = GetItemInfo(nFoodId)
						if sFood == nil then
							sFood = "not-yet-cached"
						end
					end
					local nRepId = Vtg_tItemIdToRepId[nFoodId][1]
					_, nRep, nMaxRep, sFriendName, _, _, sRepLevel = GetFriendshipReputation(nRepId)
					oTip:AddLine(VtgPrefixIngredient .. sFood .. " " .. VtgPrefix .. sFriendName .. " (" .. sRepLevel .. " " .. format("%i",((nRep*100)/nMaxRep)) .. "%)")
				end
			end
			if Vtg_tItemIdToRepId[nItemId] then
				for _, nRepId in pairs(Vtg_tItemIdToRepId[nItemId]) do
					_, nRep, nMaxRep, sFriendName, _, _, sRepLevel = GetFriendshipReputation(nRepId)
					oTip:AddLine(VtgPrefix .. sFriendName .. " (" .. sRepLevel .. " " .. format("%i",((nRep*100)/nMaxRep)) .. "%)")
				end
				oTip:Show()
			end
		end
	end
end

------------------------------------------------------------------------------------------------------
-- OnTooltipSetUnit
local function VtgOnTooltipSetUnit(oTip, ...)
	local sName, iUnit = oTip:GetUnit()
	if iUnit then
		local guidUnit = UnitGUID(iUnit)
		if guidUnit then
			local nNpcId = tonumber(guidUnit:sub(6, 10), 16)
			if nNpcId then
				local nRepId = Vtg_tNpcIdToRepId[nNpcId]
				if nRepId then
					_, nRep, nMaxRep, sFriendName, _, _, sRepLevel = GetFriendshipReputation(nRepId)
					oTip:AddLine(VtgPrefixNPC .. sRepLevel .. " " .. format("%i",((nRep*100)/nMaxRep)) .. "%")
					oTip:Show()
				end
			end
		end
	end
end

------------------------------------------------------------------------------------------------------
-- Slash functions
function VtgList()
	for _, nRepId in pairs(Vtg_tNpcIdToRepId) do
		_, nRep, nMaxRep, sFriendName, _, _, sRepLevel = GetFriendshipReputation(nRepId)
		print("|cffFFA500" .. sFriendName .. " |cffC0C0C0" .. sRepLevel .. " |cffFFA500" .. format("%i",((nRep*100)/nMaxRep)) .. "%" )
	end
end
SLASH_VTG_REPLIST1 = "/replist"
SlashCmdList["VTG_REPLIST"] = VtgList

SLASH_VTG_VER1 = "/vtg"
SlashCmdList["VTG_VER"] = function() print("Vlud's Tiller Gifts",GetAddOnMetadata("VludsTillerGifts", "Version")) end

------------------------------------------------------------------------------------------------------
-- Initialise
local function VtgInitialise()
	GameTooltip:HookScript("OnTooltipSetItem", VtgOnTooltipSetItem)
	ItemRefTooltip:HookScript("OnTooltipSetItem", VtgOnTooltipSetItem)
	ShoppingTooltip1:HookScript("OnTooltipSetItem", VtgOnTooltipSetItem)
	ShoppingTooltip2:HookScript("OnTooltipSetItem", VtgOnTooltipSetItem)
	ShoppingTooltip3:HookScript("OnTooltipSetItem", VtgOnTooltipSetItem)
	GameTooltip:HookScript("OnTooltipSetUnit", VtgOnTooltipSetUnit)
end

-- Run Init
VtgInitialise()

------------------------------------------------------------------------------------------------------
